@@ -7,6 +7,7 @@ import os
 import subprocess
 
 import click
+from click import echo
 
 
 @click.group()
@@ -19,8 +20,8 @@ def spells() -> None:
 
 @click.command()
 @click.argument("packagename")
-@click.option("-o", default="y", help="If test should be run")
-def heal(packagename: str, o: str) -> None:  # pragma: no cover
+@click.option("-t", default="y", help="If test should be run")
+def heal(packagename: str, t: str) -> None:  # pragma: no cover
     """
     One of Lias most basic spells.
 
@@ -38,8 +39,8 @@ def heal(packagename: str, o: str) -> None:  # pragma: no cover
 
     :doc-author: Julian M. Kleber
     """
-
-    assert o in ["y", "n"], "Plase specify -t as y/n"
+    say_message()
+    assert t in ["y", "n"], "Plase specify -t as y/n"
     assert os.path.isdir(packagename)
     if not packagename.endswith("/"):
         packagename += "/"
@@ -71,17 +72,24 @@ def heal(packagename: str, o: str) -> None:  # pragma: no cover
     )
     subprocess.run(
         [f"prettify-py format-dir {packagename}"], shell=True, check=True)
-    if o == "y":
+    if t == "y":
         subprocess.run(["python -m pytest tests/"], shell=True, check=True)
 
 
 @click.command()
-def deploy() -> None:
+@click.option("-t", default="y", help="If test should be run")
+def deploy(t: str) -> None:
     """
     Deployment routine
 
     :author: Julian M. Kleber
     """
+    say_message()
+    if t == "y":
+        out = subprocess.run(
+            ["python -m pytest tests/"], shell=True, check=True, capture_output=True
+        )
+        assert "FAILED" not in str(out)
     if os.path.isdir("dist") is True:
         subprocess.run(["rm -r dist "], shell=True, check=True)
     if os.path.isdir("build") is True:
@@ -91,6 +99,15 @@ def deploy() -> None:
     subprocess.run(["python3 -m twine upload dist/*"], shell=True, check=True)
 
 
+def say_message() -> None:
+
+    message = (
+        "Lia is an open-source CI/CD tool that eliminates the Fel"
+        "Copyright © 2023 Soul Twin Records, as subsidiary of SailBlack Inc."
+    )
+    echo(message=message)
+
+
 spells.add_command(heal)
 spells.add_command(deploy)
 
